@@ -1,5 +1,5 @@
 from . import hellomsg
-from .fps_clock import FPS
+from .fps_clock import GFps
 from .utils import *
 from .frame import GFrame
 from .image import GImage
