@@ -1,11 +1,11 @@
 import time
 
 
-class FPS:
+class GFps:
     def __init__(
         self, fps: any, smooth_fix: bool = False, no_limit: bool = False
     ) -> None:
-        super(FPS, self).__init__()
+        super(GFps, self).__init__()
         self.fps = float(fps)
         self.frame_rate = 1 / fps
         self.frame_rate_big = 1000 / fps
