@@ -32,8 +32,11 @@ class GImage:
         self.auto_size = auto_size
         self.stretch = stretch
         self.is_visible = True
-        self.catch_mouse = False
+        self.catch_mouse = True
+        self.is_colliding = False
+        self.is_enabled = True
         self.is_pressed = False
+        self.last_btn = 0
         self.catch_keyboard = False
         self.alpha_blend = alpha_blend
         self.update_image(image)
@@ -103,3 +106,31 @@ class GImage:
 
     def on_mouse_leave(self, x: int, y: int) -> None:
         pass
+
+    def on_mouse_enter(self):
+        pass
+
+    def on_click(self, x, y):
+        pass
+
+    def on_mouse_move_(self, x: int, y: int) -> None:
+        if self.is_pressed and self.last_btn == 1:
+            if not is_object_colliding(self, x, y):
+                self.is_colliding = False
+                return self.on_mouse_move(x, y)
+        if not self.is_colliding:
+            self.is_colliding = True
+            self.on_mouse_enter()
+        self.on_mouse_move(x, y)
+
+    def on_mouse_leave_(self, x: int, y: int) -> None:
+        self.is_colliding = False
+        self.on_mouse_leave(x, y)
+
+    def on_mouse_down_(self, x: int, y: int, button: int = 0) -> None:
+        self.on_mouse_down(x, y, button)
+
+    def on_mouse_up_(self, x: int, y: int, button: int = 0) -> None:
+        self.on_mouse_up(x, y, button)
+        if self.last_btn == button == 1 and self.is_colliding:
+            self.on_click(x, y)
