@@ -45,6 +45,8 @@ class GWinButton:  # TODO: add GAnimatedWinButton
         self.border_color = (173, 173, 173)
         self.border_hover_color = (0, 120, 215)
         self.border_click_color = (1, 85, 154)
+        self.disabled_color = (204, 204, 204)
+        self.disabled_hover_color = (191, 191, 191)
         self.border_radius = border_radius
         self.border_top_left_radius = border_top_left_radius
         self.border_top_right_radius = border_top_right_radius
@@ -77,6 +79,32 @@ class GWinButton:  # TODO: add GAnimatedWinButton
 
     def draw(self, delta: int, parent: GFrame):
         self.surf.fill((0, 0, 0, 0))
+        if not self.is_enabled:
+            pygame.draw.rect(
+                self.surf,
+                self.disabled_color,
+                (0, 0, self.w, self.h),
+                0,
+                self.border_radius,
+                self.border_top_left_radius,
+                self.border_top_right_radius,
+                self.border_bottom_left_radius,
+                self.border_bottom_right_radius
+            )
+            pygame.draw.rect(
+                self.surf,
+                self.disabled_hover_color,
+                (0, 0, self.w, self.h),
+                1,
+                self.border_radius,
+                self.border_top_left_radius,
+                self.border_top_right_radius,
+                self.border_bottom_left_radius,
+                self.border_bottom_right_radius
+            )
+            self.surf.blit(self.label.orig_image, self.label_pos)
+            self.surface.blit(self.surf, (self.x + self.parent.scroll_x, self.y + self.parent.scroll_y))
+            return
         col, b_col = (self.click_color, self.border_click_color) if self.is_pressed and self.last_btn == 1 else ((self.hover_color, self.border_hover_color) if self.is_colliding else (self.color, self.border_color))
         pygame.draw.rect(
             self.surf,
